%
% Computation of the standard interconnection structure M(s) - Delta for
% robust stability of a closed loop rigid+flexible airplane.
%
% The 20 non-repeated parametric uncertainties are ordered as:
%
%  1 to 14: Ybeta Yp Yr Ydp Ydr Lbeta Lp Lr Ldp Ldr Nbeta Np Nr Ndr
% (uncertainties of the rigid airplane)
% 15 to 20: natural frequencies of the 6 bending modes
%
% A weighting factor is introduced on the uncertainties,
% so that a normalized parametric uncertainty inside [-1,1] corresponds
% to +/- 10 % on the true parameter.
%
% See for further details:
% G. Ferreres,
% "A pratical approach for robustness analysis with aeronautical applications",
% Kluwer Academic/Plenum Publishers, 1999.
%
clear;
%
load rigid_airplane_lft;
%
load flexible_airplane_open_loop;
%
% Introduction of uncertainties in the natural frequencies
% of the bending modes.
%
% Choice of a weighting factor on uncertainties
%
weightings=0.1*ones(6,1);
%
[as,bs,cs,ds]=ssdata(sys_flexible_airplane);
Aaug2=as;
Baug2=bs;
Caug2=cs;
Daug2=ds;
for i=1:6
  idx=[(2*i-1) 2*i];
  aa=as(idx,idx);
  xx=sqrt(-aa(2,1));
  bb=zeros(12,1);
  bb(2*i)=sqrt(2*weightings(i))*xx;
  cc=zeros(1,12);
  cc(2*i-1)=sqrt(2*weightings(i))*xx;
  Baug2=[Baug2 bb];
  Caug2=[Caug2; cc];
  Daug2=mdiag(Daug2,0);
end
blk2=[-ones(6,1) zeros(6,1)];
%
load flexible_airplane_controller;
[ak,bk,ck,dk]=ssdata(sys_k);
%
[a,b,c,d]=linmod('flexible_airplane_closed_loop');
%
fprintf('\n\n Poles of the nominal closed loop:\n');
damp(a);
%
sys_M=ss(a,b,c,d);
blk=[blk; blk2];
%
save flexible_airplane_m_delta sys_M blk;
 