%
% Computation of the standard interconnection structure M(s) - Delta for
% robust stability and performance of a closed loop rigid missile.
%
% The 4 non-repeated parametric uncertainties are ordered as:
%
% czalfa, cmalfa, czeta and cmeta, where eta is the input.
%
% A block of neglected dynamics and a performance block have also
% been introduced, with dynamical templates.
%
% A weighting factor is introduced on the parametric uncertainties,
% so that a normalized parametric uncertainty inside [-1,1] corresponds
% to +/- 5 % on the true parameter.
%
% The missile model was linearized at alfa = 10 degrees.
%
% The nonlinear missile model was introduced by:
% R.T. Reichert,
% "Dynamic scheduling of modern robust control autopilot design for missiles",
% IEEE Control Systems magazine,
% vol. 12, n. 5, pp. 35-42, October 1992.
%
clear;
%
load missile_lft;
%
% Inputs/outputs of the standard interconnection structure:
%
% 1-4: uncertainties in the stability derivatives.
% 5  : for performance block.
% 6  : additive neglected dynamics.
%
[a,b,c,d]=linmod('missile_closed_loop');
blk1=[-ones(4,1) zeros(4,1); ones(2,1) zeros(2,1)];
sys_M1=ss(a,b,c,d);
fprintf('\n\n Poles of the nominal closed loop (with dynamical templates):\n');
damp(sys_M1);
size(sys_M1);
fprintf('\n Strike any key to continue...');
pause
%
num_Wadd_old=num_Wadd;
den_Wadd_old=den_Wadd;
num_Wperf_old=num_Wperf;
den_Wperf_old=den_Wperf;
%
num_Wadd=1;
den_Wadd=1;
[a,b,c,d]=linmod('missile_closed_loop');
blk2=[-ones(4,1) zeros(4,1); 1 0];
sys_M2=ss(a,b,c,d);
sys_M2=sys_M2(1:5,1:5);
fprintf('\n\n Poles of the nominal closed loop (with a dynamical template for performance):\n');
damp(sys_M2);
size(sys_M2);
fprintf('\n Strike any key to continue...');
pause
%
num_Wperf=1;
den_Wperf=1;
[a,b,c,d]=linmod('missile_closed_loop');
blk3=[-ones(4,1) zeros(4,1)];
sys_M3=ss(a,b,c,d);
sys_M3=sys_M3(1:4,1:4);
fprintf('\n\n Poles of the nominal closed loop (without dynamical templates):\n');
damp(sys_M3);
size(sys_M3);
fprintf('\n Strike any key to continue...');
pause
%
num_Wadd=num_Wadd_old;
den_Wadd=den_Wadd_old;
[a,b,c,d]=linmod('missile_closed_loop');
blk4=[-ones(4,1) zeros(4,1); 1 0];
sys_M4=ss(a,b,c,d);
sys_M4=sys_M4([1:4 6],[1:4 6]);
fprintf('\n\n Poles of the nominal closed loop (with a dynamical template for neglected dynamics):\n');
damp(sys_M4);
size(sys_M4);
fprintf('\n Strike any key to continue...');
pause
%
save missile_m_delta sys_M1 sys_M2 sys_M3 sys_M4 blk1 blk2 blk3 blk4;
