%
% On the missile example, computation of worst-case gain, phase and delay margins
% (with the small gain theorem) in the presence of parametric uncertainties.
%
clear;
%
load missile_lft;
blk=[-ones(4,1) zeros(4,1)];
%
% The weighting factor is 5 % on the parametric uncertainties, so that
% when model uncertainties are maintained inside their unit ball, this
% means that parametric uncertainties vary between +/- 5 %.
%
% This weighting factor is increased below, so that parametric
% uncertainties vary between +/- 15 %.
%
Baug(:,2:5)=Baug(:,2:5)*sqrt(3);
Caug(3:6,:)=sqrt(3)*Caug(3:6,:);
Daug(3:6,2:5)=3*Daug(3:6,2:5);
%
% Computation of the 1st standard interconnection structure, where delays
% are introduced as direct model perturbations.
%
[a,b,c,d]=linmod('demo_delays_1');       
[t,a]=balance(a); b=t\b; c=c*t;
sys1=ss(a,b,c,d);
%
% Computation of the 2d standard interconnection structure, where delays
% are introduced as inverse model perturbations.
%
[a,b,c,d]=linmod('demo_delays_2');       
[t,a]=balance(a); b=t\b; c=c*t;
sys2=ss(a,b,c,d);
%
% Frequency gridding (it will be refined inside worst_case_margin.m)
%
puls0=[0 logspace2(1e-1,1000,200)];
%
improved_delay_margin=input2('Improvement of the delay margin (0/1): ',1);
%
rep=input2('Complete (1) problem or simplified (0) one, with no parametric uncertainties: ',0);
if rep==0 blk=[]; sys1=sys1(5:7,5:7);  sys2=sys2(5:7,5:7); end
%
[puls,tab_delay,tab_phase,tab_gain]=worst_case_margin(sys1,sys2,blk,puls0,improved_delay_margin);
%
figure(1);
clf;
loglog(puls,tab_delay);
title('delay margin');
xlabel('rad/s');
ylabel('s');
%
figure(2);
clf;
semilogx(puls,tab_phase);
title('phase margin');
xlabel('rad/s');
ylabel('deg');
%
figure(3);
clf;
plot(puls,tab_gain(:,1),puls,tab_gain(:,2));
title('gain margin');
xlabel('rad/s');
