%
% On the missile example, computation of worst-case values for the delays,
% in the case without parametric uncertainties, using time-domain simulations.
%
clear;
%
load missile_lft;
%
% The weighting factor is 5 % on the parametric uncertainties, so that
% when model uncertainties are maintained inside their unit ball, this
% means that parametric uncertainties vary between +/- 5 %.
%
% This weighting factor is increased below, so that parametric
% uncertainties vary between +/- 15 %.
%
Baug(:,2:5)=Baug(:,2:5)*sqrt(3);
Caug(3:6,:)=sqrt(3)*Caug(3:6,:);
Daug(3:6,2:5)=3*Daug(3:6,2:5);
%
% Worst-case values of the parametric uncertainties
%
Delta_wc=[0 0 0 0];
Delta_wc=diag(Delta_wc);
%
fprintf('\n\nComputation of worst-case values for the 3 delays in the case without parametric uncertainties\n\n');
%
while 1
%
  tau_max=input2('guess value of the delay margin in ms (0 to stop): ',[]);
  if tau_max==0 break; end
  tau_max=1e-3*tau_max;
  tab=hypercube(3);
  for i=1:size(tab,1)
    for j=1:size(tab,2)
      if tab(i,j)==-1 tab(i,j)=0; else tab(i,j)=tau_max; end
    end
  end
%
  warning off;
  figure(1);
  clf;
  fprintf('\n');
  for i=1:size(tab,1) 
    tau1=tab(i,1);
    tau2=tab(i,2);
    tau3=tab(i,3);
    [T,x,y]=sim('demo_delays_3',10);
    hold on;
    plot(T,y(:,1));
    fprintf('delays = %6.3f ms, %6.3f ms, %6.3f ms: overshoot = %6.3f percent\n',...
    1e3*tau1,1e3*tau2,1e3*tau3,100*(max(y(:,1))-1));
  end
  xlabel('s');
  warning on;
  fprintf('\nSee also figure 1\n\n')
%
end
