function puls=calc_freq_gridding_bending(sys_M)
%
% call:  puls=calc_freq_gridding_bending(sys_M)
%
% Computation of a frequency gridding around the bending modes in sys_M.
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin~=1 error('CALC_FREQ_GRIDDING_BENDING: 1 input argument'); end
%
fprintf('\n\nPoles of M(s)\n\n');
damp(sys_M);
%
cxi_min=input2('Minimal damping ratio (under which the STABLE mode is a bending one): ',0.1);
if cxi_min>=1
  error('CALC_FREQ_GRIDDING_BENDING: wrong value of the minimal damping ratio');
end
%
N=input2('Number of points around each bending mode: ',10);
%
delta_w=input2('Dispersion around the natural frequency (0.1 means +/- 10 \%): ',0.1);
%
e=eig(sys_M);
[w,z]=damp(e);
list=find((z>=0)&(z<=cxi_min));
%
if isempty(list)
  fprintf('\n\n No bending mode\n\n');
  puls=[];
   return;
end
%
fprintf('\n\n Bending modes\n\n');
damp(e(list));
icpt=1;
puls=[];
the_end=0;
while ~the_end
  iii=list(icpt);
  qqq=logspace2((1-delta_w)*w(iii),(1+delta_w)*w(iii),N);
  puls=[puls qqq];
  icpt=icpt+2;
  the_end=(icpt>length(list));
end
