function rep_M=calc_freq_resp(sys,puls,alfa,cxi)
%
% call:  rep_M=calc_freq_resp(sys,puls,alfa,cxi)
%
% Computation of the frequency response of a continuous-time plant
% (described by system matrix sys, with ss format), possibly on
% the border of a truncated sector (see the help of
% mu_frequency_gridding.m for the meanings of alfa and cxi), on the
% frequency gridding puls.
%
% alfa < 0 means that the closed loop is stable.
%
% When handling a truncated sector, frequency puls(iw) corresponds to the point
% s0 of the border of the truncated sector satisfying Im(s0)=puls(iw).
%
% rep_M(:,:,iw) is the frequency response at puls(iw).
%
% if alfa=0 and cxi=0, freqresp.m is classically used, i.e. the
% frequency response is computed on the imaginary axis.
% otherwise it is computed on a truncated sector, which implies
% a non-standard call of the routine freqresp.m. Although the
% help says that this routine should only be used to compute
% frequency responses on the imaginary axis, it has been
% checked that it still works outside the imaginary axis.
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin~=4 error('CALC_FREQ_RESP: 4 input arguments'); end
%
alfa=abs(alfa);
%
nw=length(puls);
%
if (alfa==0)&(cxi==0)
  om=puls;  
else 
  theta=asin(cxi);
  q=alfa*tan(pi/2-theta);
  om=[];
  for i=1:nw
    if puls(i)<=q
      om(i)=-alfa+sqrt(-1)*puls(i);
    else
      om(i)=(-tan(theta)+sqrt(-1))*puls(i);
    end
  end
end;

rep_M=freqresp(sys,om);
 

