function [puls,wc] = gen_grid(sys,a2,a3,a4);
%
% calls : [puls,wc]  = gen_grid(sys);
%         [puls,wc]  = gen_grid(sys,N);
%         [puls,wc]  = gen_grid(sys,wmin,wmax);
%         [puls,wc]  = gen_grid(sys,wmin,wmax,N);
%
% This function generates a frequency gridding containing N points
% between wmin and wmax. The gridding is automatically refined in
% frequency regions containing flexible modes.
% 
% Defaults values are:
%   N = 50
%   wmin, wmax : computed according to the system bandwidth
%
% Outputs :
%  puls : frequency gridding
%  wc   : frequency point around which numerous flexible modes appear
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin <1,
    error('Gen_grid : wrong number of input arguments');
end;

if nargin==1,
    N=50; wmin=[]; wmax=[];
elseif nargin==2,
    N=a2;
    wmin=[]; wmax=[];
elseif nargin==3,
    wmin=a2; wmax=a3; N=50;
elseif nargin==4,
    wmin=a2; wmax=a3; N=a4;
end;

[w0,z0]=damp(sys);
n=length(w0);

if isempty(wmin),
        w2=max(w0); wtest=1d-5;
        while w2>wtest,
            wtest=wtest*10;
        end;
        wmax=wtest;
        w1=min(w0); wtest=1d5;
        while w1<wtest,
             wtest=wtest/10;
        end;
        wmin=wtest;
end;


jj=1; w=[]; z=[];
while jj<=n,
   w=[w w0(jj)];
   z=[z z0(jj)];
   if z0(jj)<1,
       jj=jj+2;
   else
       jj=jj+1;
   end;
end;
clear w0; clear z0;

nI=floor(N/5)+1;
lgI=(wmax-wmin)/nI;
w0=[wmin:lgI:wmax];
Nr=N-nI-1;

c=zeros(1,nI);
ii=1; nw=length(w); jj=1; test=1;
while (jj<=nw) & test,
    if ((w(jj)>=w0(ii)) & (w(jj)<=w0(ii+1))) ,
            c(ii)=c(ii)+1/z(jj);
    else
            ii=ii+1;
            c(ii)=c(ii)+1/z(jj);
    end;
    test=(w(jj)<=wmax);
    jj=jj+1;
end;

c=round(Nr*c/sum(c));
nrr=sum(c)-Nr;
if nrr>0,
    [cmax,indcm]=max(c);
    c(indcm)=cmax-nrr;
end;

puls=[];
nimax=0;
wc=[];
for ii=1:nI,
    if c(ii)>0,
        ni=c(ii)+1;
        lgi=(w0(ii+1)-w0(ii))/ni;
        if ni>nimax, 
            nimax=ni; 
            wc=(w0(ii+1)+w0(ii))/2;
        end;
        wi=linspace(w0(ii)+lgi,w0(ii+1)-lgi,c(ii));
        puls=[puls w0(ii) wi];
    else
        puls=[puls w0(ii)];
    end;
    
end;
puls=[puls w0(nI+1)];
if isempty(wc),
    wc=mean(puls);
end;

if puls(1)~=0,
    puls=[0 puls];
end;
