function out=input2(message,default_value,tab_valid_value)
%
% call:  out=input2(message,default_value)
%        out=input2(message,default_value,tab_valid_value)
%
% Sophisticated version of input.m
%
% If there's no default value please choose default_value=[]
%
% A scalar (real or integer) must be asked for, not a vector / matrix / string value.
%
% tab_valid_value is the vector of possible valid values.
%
% After entering a value, a test is performed if this value belongs
% to the list tab_valid_value,
% except if tab_valid_value is undefined or tab_valid_value = [].
%
% examples:
%
% out=input2('lambda = ',1);
%
% If the user just strikes "enter", out will be equal to 1.
%
% out=input2('lambda = ',[]);
%
% The user must enter a value, if he/she strikes "enter",
% the question appears again.
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin==2
  tab_valid_value=[];
elseif nargin~=3
  error('INPUT2: 2 or 3 input arguments');
end
%
if ~isempty(default_value)
  if round(default_value)==default_value
    fprintf('\nDefault value is %i\n',default_value);
  else
    fprintf('\nDefault value is %6.3e\n',default_value);
  end
end
%
while 1
  out=input(message);
  if isempty(out) out=default_value; end
  if ~isempty(out)
    out=out(:);
    if length(out)~=1 error('INPUT2: only a scalar can be asked for'); end
    if isempty(tab_valid_value)
      break;
    elseif any(out==tab_valid_value)
      break;
    end
  end
end
