function mu_locus(sys,delta_matrix,arg_color)
%
% call:  mu_locus(sys,delta_matrix,arg_color)
%
% sys = system matrix of M(s) (with "ss" format)
%
% delta_matrix = a square structured model perturbation
%
% the root locus is drawn for the interconnection of M(s)
% with alfa*delta_matrix, when alfa varies between 0 and 1.
%
% arg_color determines the color of the plot, e.g. :
% arg_color='g' or arg_color='m'
% (a single character)
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin~=3  error('MU_LOCUS: 3 input arguments'); end
%
[a,b,c,d]=ssdata(sys);
%
% a gridding of N points between 0 and 1 for alfa
%
N=50;
%
alfa=0;
for i=1:(N+1)
  Delta=alfa*delta_matrix;
  abf=a+b*Delta*inv(eye(size(Delta))-d*Delta)*c;
  e=eig(abf);
  [qqq1,qqq2]=sort(abs(e)); e=e(qqq2);
  if i==1
    tab_e=e;
  else
    e_old=tab_e(:,size(tab_e,2));
    e_new=[];
    for j=1:length(e_old)
      qqq=abs(e-e_old(j));
      [qqq,k]=min(qqq);
      e_new(j)=e(k);
      e(k)=Inf;
    end
    tab_e=[tab_e e_new(:)];
  end
  alfa=alfa+1/N;
end
%
% visualisation of the locus
%
hold_or_not=ishold;
%
for i=1:size(tab_e,1)
  qqq=tab_e(i,:);
  plot(real(qqq),imag(qqq),arg_color);
  if i==1 hold on; end
end
%
% visualisation of the initial and final positions of the poles
%
qqq=tab_e(:,1);
plot(real(qqq),imag(qqq),[arg_color,'*']);
qqq=tab_e(:,end);
plot(real(qqq),imag(qqq),[arg_color,'x']);
%
if ~hold_or_not hold off; end
%
title('initial (*) and final (x) positions of the poles');
