function plot_bar(tabx,taby,a1,a2)
%
% PLOT_BAR                                     -  Plots bar diagram
%------------------------------------------------------------------
% PURPOSE
% This routine is used to display  guaranteed  mu-upper bounds as a
% function of frequency segments.
%
% SYNOPSIS
% plot_bar(tabx,taby,axtyp,pltyp);
% plot_bar(tabx,taby,pltyp); (default value for axtyp is 'lin')
% plot_bar(tabx,taby,'lin');
% plot_bar(tabx,taby,'log');
%
% INPUT ARGUMENTS
% tabx    N-by-2 array defining the frequency segments on x-axis
% taby    N-by-1 array defining the values on the y-axis
% axtyp   character string defining the axis type along x
%         'lin' : linear x-axis
%         'log' : logarithmic x-axis
% pltyp   character string defining the plot type and colour
%         (see plot function)
if nargin<2
  error('PLOT_BAR: wrong number of input arguments');
end
pltyp=''; axtyp='lin';
if nargin==4,
    pltyp=a2;
    axtyp=a1;
elseif nargin==3,
    if strcmp(a1,'lin'),
        axtyp='lin';
    elseif strcmp(a1,'log'),
        axtyp='log';
    else
        pltyp=a1;
    end;
end;
qqq=ishold;
first_time=1;
for i=1:size(tabx,1)
  x1=tabx(i,1);
  x2=tabx(i,2);
  y=taby(i);
  if strcmp(axtyp,'lin'),
    plot([x1 x2],[y y],pltyp);
    if first_time hold on; first_time=0; end
    plot([x1 x1],[0 y],pltyp);
    plot([x2 x2],[0 y],pltyp);
  elseif (x1~=0)
    semilogx([x1 x2],[y y],pltyp);
    if first_time hold on; first_time=0; end
    semilogx([x1 x1],[0 y],pltyp);
    semilogx([x2 x2],[0 y],pltyp);
  else
    semilogx(x2,y,['d',pltyp]);
    if first_time hold on; first_time=0; end      
  end
end
if ~qqq hold off; end
