function [M2,blk2]=skew_sort(M,blk,is_ss)
%
% call:  [M2,blk2]=skew_sort(M,blk,is_ss)
%
% Transformation of the standard interconnection structure M - Delta.
%
% blk describes the structure of the model perturbation Delta.
% Uncertainties, whose norm must be less than 1, are placed
% at the beginning. blk becomes blk2, M becomes M2.
%
% M can be:
% 1/ a 2-dimensional matrix (is_ss=0).
% 2/ a 3-dimensional matrix,i.e. M(:,:,i) for i between 1 and N (is_ss=0).
% 3/ a system matrix with ss format (is_ss=1).
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin~=3 error('SKEW_SORT: 3 input arguments'); end
%
% Preliminary tests
%
if size(blk,2)~=3 error('SKEW_SORT: blk must have 3 columns'); end
%
if all(blk(:,3)==0) error('SKEW_SORT: problem with the 3th column of blk'); end
%
% Case of a classical mu problem (no skew uncertainty)
%
if all(blk(:,3)==1)
  M2=M;
  blk2=blk;
  return;
end
%
% The interconnection structure M - Delta is
% rewritten as MM - diag(Delta1,Delta2)
%
% Delta1 is the part of Delta whose norm is less than 1,
% Delta2 the part of Delta whose norm is free.
%
% A skew mu problem is necessarily considered, i.e. Delta1
% or Delta2 can not be empty (special cases were detected before).
%
icpt=1;
idx_Delta1=[];
idx_Delta2=[];
idx_blk1=[];
idx_blk2=[];
for i=1:size(blk,1)
  n=abs(blk(i,1));
  if blk(i,3)
    idx_Delta2=[idx_Delta2 icpt:(icpt+n-1)];
    idx_blk2  =[idx_blk2 i];
  else
    idx_Delta1=[idx_Delta1 icpt:(icpt+n-1)];
    idx_blk1  =[idx_blk1 i];
  end
  icpt=icpt+n;
end
%
blk2=blk([idx_blk1 idx_blk2],:);
idx=[idx_Delta1 idx_Delta2];
%
if is_ss
  M2=M(idx,idx); % system matrix
else
  M2=M(idx,idx,:);
  M2=squeeze(M2);
end
