function [M2,blk2]=square_m(M,blk,is_ss)
%
% call:  [M2,blk2]=square_m(M,blk,is_ss)
%
% Transformation of the standard interconnection structure M - Delta.
%
% blk describes the structure of the model perturbation Delta.
%
% Non-square Delta and M are transformed into square ones.
%
% If M = (m,n) then Delta must be (n,m).
%
% M can be:
% 1/ (is_ss=0) a 2-dimensional matrix.
% 2/ (is_ss=0) a 3-dimensional matrix,i.e. M(:,:,i) for i between 1 and N.
% 3/ (is_ss=1) a system matrix with ss format.
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin~=3 error('SQUARE_M: 3 input arguments'); end
%
% Preliminary tests
%
idx=find(blk(:,1)<0);
if ~isempty(idx)
  qqq=blk(idx,2);
  if any(qqq~=0)
    error('SQUARE_M: full real blocks are not allowed');
  end
end
%
idx1=0;
idx2=0;
for i =1:size(blk,1)
  m=abs(blk(i,1));
  n=abs(blk(i,2));
  if n==0 n=m; end
  idx1=idx1+m;
  idx2=idx2+n;
end
if (size(M,1)~=idx2)|(size(M,2)~=idx1)
  error('SQUARE_M: incompatible dimensions of M and Delta');
end
%
icpt=0;
M2=M;
blk2=blk;
for i=1:size(blk,1)
  m=abs(blk(i,1));
  n=abs(blk(i,2));
  if n==0 n=m; end
  if n>m
    blk2(i,1:2)=[n n];
    idx=icpt+m;
    if is_ss
      [a,b,c,d]=ssdata(M2);
      qqq1=b(:,1:idx);
      qqq2=b(:,(idx+1):end);
      b=[qqq1 zeros(size(qqq1,1),n-m) qqq2];
      qqq1=d(:,1:idx);
      qqq2=d(:,(idx+1):end);
      d=[qqq1 zeros(size(qqq1,1),n-m) qqq2];
      M2=ss(a,b,c,d);
    else
      MM=[];
      for iw=1:size(M2,3)
        qqq1=M2(:,1:idx,iw);
        qqq2=M2(:,(idx+1):end,iw);
        qqq=[qqq1 zeros(size(qqq1,1),n-m) qqq2];
        MM{iw}=qqq;
      end
      M2=[];
      for iw=1:length(MM), M2(:,:,iw)=MM{iw}; end
    end
  elseif n<m
    blk2(i,1:2)=[m m];
    idx=icpt+n;
    if is_ss
      [a,b,c,d]=ssdata(M2);
      qqq1=c(1:idx,:);
      qqq2=c((idx+1):end,:);
      c=[qqq1; zeros(m-n,size(qqq1,2)); qqq2];
      qqq1=d(1:idx,:);
      qqq2=d((idx+1):end,:);
      d=[qqq1; zeros(m-n,size(qqq1,2)); qqq2];
      M2=ss(a,b,c,d);    
    else
      MM=[];
      for iw=1:size(M2,3)
        qqq1=M2(1:idx,:,iw);
        qqq2=M2((idx+1):end,:,iw);
        qqq=[qqq1; zeros(m-n,size(qqq1,2)); qqq2];
        MM{iw}=qqq;
      end
      M2=[];
      for iw=1:length(MM), M2(:,:,iw)=MM{iw}; end
    end
  end
  icpt=icpt+max(m,n);
end
